/*
 * Copyright see libbb.c
*/

#define _GNU_SOURCE
#include <sys/types.h>
#include <sys/stat.h>
#include <stdio.h>
#include <errno.h>
#include <string.h>
#include <unistd.h>
#include <stdarg.h>
#include <stdlib.h>
#include <signal.h>
#include <getopt.h>
#include <time.h>

extern const char usage_msg[];
extern FILE *log_f;

void bb_show_usage (void);
int xgetopt(int argc, char **argv, const char *applet_opts, ...);

void reset_daemon_name(const char *new_daemon_name);
extern const char *daemon_name;
extern int daemon_mode;

void bb_error_msg_and_die(const char *s, ...) __attribute__ ((noreturn, format (printf, 1, 2)));
void bb_perror_msg_and_die(const char *s, ...) __attribute__ ((noreturn, format (printf, 1, 2)));
void bb_perror_msg(const char *s, ...) __attribute__ ((format (printf, 1, 2)));
void bb_error_msg(const char *s, ...) __attribute__ ((format (printf, 1, 2)));
void log_msg(const char *s, ...) __attribute__ ((format (printf, 1, 2)));

char *concat_path_file(const char *path, const char *filename);
void free0 (char **p);
void *xmalloc(size_t size);
char * bb_xstrdup (const char *s);
char *bb_simplify_path(const char *path);
char *bb_xasprintf(const char *format, ...) __attribute__ ((format (printf, 1, 2)));
long safe_strtol(const char *arg);
long bb_xgetpwnam(const char *name);
sigset_t bb_sigblock(unsigned int sigs_bits);
void bb_sigunblock(sigset_t m);
FILE *xwafopen(const char *name, const char *xtype);

unsigned int safe_strtol16(const char *arg, char **e);
long long safe_strtoll16(const char *arg, char **endptr);
int bb_xferror(FILE *fp, const char *fn);

/* common my function, no bb library */

void xstat(const char *name, struct stat *pst);

char *make_fullpath_and_tstisdir(const char *d);
void tst_is_one_fs(const char *d1, const char *d2);
int tst_is_not_one_fs(const char *d1, const char *d2);

FILE *create_pid_file_and_lock(const char *pidfile);
void write_pid(FILE *fl);

void xdaemon(int change_dir_to_root, const char *pidfile);

void unlink_pidfile(void);
